SystemOrganization addCategory: #ConfigurationOfSightDynamic!

Object subclass: #ConfigurationOfSightDynamic
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSightDynamic'!

!ConfigurationOfSightDynamic class methodsFor: 'development support' stamp: 'mt 4/27/2011 13:46:00.637'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfSightDynamic class methodsFor: 'private' stamp: 'mt 4/27/2011 13:46:00.748'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfSightDynamic class methodsFor: 'private' stamp: 'mt 4/27/2011 13:46:00.8'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfSightDynamic class methodsFor: 'private' stamp: 'mt 4/27/2011 13:46:00.867'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfSightDynamic class methodsFor: 'metacello tool support' stamp: 'mt 4/27/2011 13:46:00.939'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSightDynamic class methodsFor: 'loading' stamp: 'mt 4/27/2011 13:46:01.002'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfSightDynamic class methodsFor: 'loading' stamp: 'mt 4/27/2011 13:46:01.059'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfSightDynamic class methodsFor: 'loading' stamp: 'mt 4/27/2011 13:46:01.115'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfSightDynamic class methodsFor: 'loading' stamp: 'mt 5/2/2011 13:10:19.659'!
loadSnapshot
	"Load the latest snapshot which may be buggy but is not equivalent with the current head #development version."

	"self loadSnapshot"

	<apiDocumentation>
	^(self project version: #snapshot) load! !

!ConfigurationOfSightDynamic class methodsFor: 'accessing' stamp: 'mt 4/27/2011 13:46:01.168'!
project

	^self new project! !

!ConfigurationOfSightDynamic class methodsFor: 'development support' stamp: 'mt 4/27/2011 13:46:00.7'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfSightDynamic methodsFor: 'baselines' stamp: 'mt 4/27/2011 15:20:16.24'!
baseline100: spec 
	<version: '1.0-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/CodeSight'.
					
		spec project: 'Signals' with: [
			spec
				className: 'ConfigurationOfSignals';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Animations' with: [
			spec
				className: 'ConfigurationOfAnimations';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Widgets' with: [
			spec
				className: 'ConfigurationOfWidgets';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository';
				loads: #(full)].

		spec project: 'OCompletion' with: [
			spec
				className: 'ConfigurationOfOCompletion';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].

		spec project: 'CodeSight' with: [
			spec
				className: 'ConfigurationOfAnimations';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository';
				loads: #(cst)].

		spec package: 'VB-Regex' with: [
			spec repository: 'http://www.squeaksource.com/Regex'].
					
		spec package: 'Icons' with: [
			spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'].
		
		spec package: 'Fonts' with: [
			spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/swaprivate'].

		spec package: 'Sight-Dynamic' with: [
			spec
				requires: #(Animations Signals 'VB-Regex' Widgets Icons Fonts OCompletion);
				postLoadDoIt: #postLoad].

		spec
			group: 'default' with: #('Sight-Dynamic');
			group: 'full' with: #('Sight-Dynamic' CodeSight)].! !

!ConfigurationOfSightDynamic methodsFor: 'symbolic versions' stamp: 'mt 4/27/2011 14:33:58.174'!
development: spec 
	<symbolicVersion: #development>
	
	spec for: #'common' version: '1.0'.
! !

!ConfigurationOfSightDynamic methodsFor: 'postload' stamp: 'mt 5/2/2011 14:29:26.66'!
postLoad

	| normal small mono |
	SdTextStyler initialize.
	
	"Setup fonts."
	normal := StrikeFont familyName: #'Bitmap Segoe UI' size: 9.
	small := StrikeFont familyName: #'Bitmap DejaVu Sans' size: 7.
	mono := StrikeFont familyName: #'Bitmap Envy Code R' size: 10.
	Preferences
		setSystemFontTo: normal;
		setListFontTo: normal;
		setHaloLabelFontTo: mono;
		setMenuFontTo: normal;
		setWindowTitleFontTo: (normal emphasized: 1 "bold");
		setBalloonHelpFontTo: small;
		setCodeFontTo: mono;
		setButtonFontTo: normal.! !

!ConfigurationOfSightDynamic methodsFor: 'accessing' stamp: 'mt 4/27/2011 13:46:00.421'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSightDynamic methodsFor: 'symbolic versions' stamp: 'mt 5/2/2011 13:10:52.277'!
snapshot: spec
	<symbolicVersion: #snapshot>
	
	spec for: #'common' version: '0.1'.! !

!ConfigurationOfSightDynamic methodsFor: 'versions' stamp: 'mt 5/2/2011 14:05:53.57'!
version010: spec

	<version: '0.1' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #snapshot.
		spec author: 'Marcel Taeumel'.
		
		spec
			project: 'Signals' with: '1.0.3';
			project: 'Animations' with: '1.0.2';
			project: 'Widgets' with: '1.1-snapshot-110502';
			project: 'CodeSight' with: #development; "TODO: make fixed!!"
			project: 'OCompletion' with: '1.2.2'.
			
		spec
			package: 'VB-Regex' with: 'VB-Regex-damienpollet.17';
			package: 'Icons' with: 'Icons-mt.1';
			package: 'Fonts' with: 'Fonts-mt.1';
			package: 'Sight-Dynamic' with: 'Sight-Dynamic-mt.64'].! !

!ConfigurationOfSightDynamic methodsFor: 'versions' stamp: 'mt 4/27/2011 14:56:04.194'!
version100: spec

	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #development.
		spec author: 'Marcel Taeumel'.
		
		spec
			project: 'Signals' with: #development;
			project: 'Animations' with: #development;
			project: 'Widgets' with: #development;
			project: 'CodeSight' with: #development;
			project: 'OCompletion' with: #stable.
			
		spec
			package: 'VB-Regex' with: 'VB-Regex-damienpollet.17';
			package: 'Icons' with: 'Icons-mt.1';
			package: 'Fonts' with: 'Fonts-mt.1'].! !
